@@ -18,16 +18,21 @@ fi
 
 autoreconf -i -f
 
-run_configure=true
-for arg in $*; do
-    case $arg in
-        --no-configure)
-            run_configure=false
-            ;;
-        *)
-            ;;
-    esac
-done
+# Honor NOCONFIGURE for compatibility with gnome-autogen.sh
+if test x"$NOCONFIGURE" = x; then
+    run_configure=true
+    for arg in $*; do
+        case $arg in
+            --no-configure)
+                run_configure=false
+                ;;
+            *)
+                ;;
+        esac
+    done
+else
+    run_configure=false
+fi
 
 if test $run_configure = true; then
     ./configure "$@"
