@@ -11,8 +11,7 @@
 
 #include "config.h"
 
-#include <telepathy-glib/debug.h>
-#include <telepathy-glib/run.h>
+#include <telepathy-glib/telepathy-glib.h>
 
 #include "examples/cm/channelspecific/connection-manager.h"
 
