@@ -231,7 +231,7 @@ new_channel (ExampleEcho2ImManager *self,
   GSList *requests = NULL;
 
   object_path = g_strdup_printf ("%s/Echo2Channel%u",
-      self->priv->conn->object_path, handle);
+      tp_base_connection_get_object_path (self->priv->conn), handle);
 
   chan = g_object_new (EXAMPLE_TYPE_ECHO_2_CHANNEL,
       "connection", self->priv->conn,
@@ -319,12 +319,13 @@ example_echo_2_im_manager_request (ExampleEcho2ImManager *self,
 
   if (chan == NULL)
     {
-      new_channel (self, handle, self->priv->conn->self_handle,
+      new_channel (self, handle,
+          tp_base_connection_get_self_handle (self->priv->conn),
           request_token);
     }
   else if (require_new)
     {
-      g_set_error (&error, TP_ERRORS, TP_ERROR_NOT_AVAILABLE,
+      g_set_error (&error, TP_ERROR, TP_ERROR_NOT_AVAILABLE,
           "An echo2 channel to contact #%u already exists", handle);
       goto error;
     }
