@@ -35,14 +35,14 @@
  * Deprecated: 0.11.7
  */
 
+#include "config.h"
+
 #include <telepathy-glib/channel-factory-iface.h>
 
 #include <glib-object.h>
 
 #include <telepathy-glib/channel-iface.h>
 
-#include "_gen/signals-marshal.h"
-
 enum {
     NEW_CHANNEL,
     CHANNEL_ERROR,
@@ -81,8 +81,7 @@ tp_channel_factory_iface_base_init (gpointer klass)
                   G_OBJECT_CLASS_TYPE (klass),
                   G_SIGNAL_RUN_LAST | G_SIGNAL_DETAILED,
                   0,
-                  NULL, NULL,
-                  _tp_marshal_VOID__OBJECT_POINTER,
+                  NULL, NULL, NULL,
                   G_TYPE_NONE, 2, G_TYPE_OBJECT, G_TYPE_POINTER);
 
     /**
@@ -102,8 +101,7 @@ tp_channel_factory_iface_base_init (gpointer klass)
                   G_OBJECT_CLASS_TYPE (klass),
                   G_SIGNAL_RUN_LAST | G_SIGNAL_DETAILED,
                   0,
-                  NULL, NULL,
-                  _tp_marshal_VOID__OBJECT_POINTER_POINTER,
+                  NULL, NULL, NULL,
                   G_TYPE_NONE,
                   3, G_TYPE_OBJECT, G_TYPE_POINTER, G_TYPE_POINTER);
   }
