@@ -19,6 +19,10 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
+#if defined (TP_DISABLE_SINGLE_INCLUDE) && !defined (_TP_IN_META_HEADER) && !defined (_TP_COMPILATION)
+#error "Only <telepathy-glib/telepathy-glib.h> and <telepathy-glib/telepathy-glib-dbus.h> can be included directly."
+#endif
+
 #ifndef __TP_CONNECTION_H__
 #define __TP_CONNECTION_H__
 
@@ -48,6 +52,12 @@ TpContactInfoFieldSpec *tp_contact_info_field_spec_copy (
     const TpContactInfoFieldSpec *self);
 void tp_contact_info_field_spec_free (TpContactInfoFieldSpec *self);
 
+#ifndef __GI_SCANNER__
+/* the typedef only exists for G_DEFINE_BOXED_TYPE's benefit, and
+ * g-ir-scanner 1.32.1 doesn't parse a skip annotation */
+typedef GList TpContactInfoSpecList;
+#endif
+
 #define TP_TYPE_CONTACT_INFO_SPEC_LIST (tp_contact_info_spec_list_get_type ())
 GType tp_contact_info_spec_list_get_type (void);
 GList *tp_contact_info_spec_list_copy (GList *list);
@@ -71,6 +81,12 @@ TpContactInfoField *tp_contact_info_field_new (const gchar *field_name,
 TpContactInfoField *tp_contact_info_field_copy (const TpContactInfoField *self);
 void tp_contact_info_field_free (TpContactInfoField *self);
 
+#ifndef __GI_SCANNER__
+/* the typedef only exists for G_DEFINE_BOXED_TYPE's benefit, and
+ * g-ir-scanner 1.32.1 doesn't parse a skip annotation */
+typedef GList TpContactInfoList;
+#endif
+
 #define TP_TYPE_CONTACT_INFO_LIST (tp_contact_info_list_get_type ())
 GType tp_contact_info_list_get_type (void);
 GList *tp_contact_info_list_copy (GList *list);
@@ -124,26 +140,44 @@ GQuark tp_errors_disconnected_quark (void);
   (G_TYPE_INSTANCE_GET_CLASS ((obj), TP_TYPE_CONNECTION, \
                               TpConnectionClass))
 
+_TP_DEPRECATED_IN_0_20_FOR(tp_simple_client_factory_ensure_connection)
 TpConnection *tp_connection_new (TpDBusDaemon *dbus, const gchar *bus_name,
     const gchar *object_path, GError **error) G_GNUC_WARN_UNUSED_RESULT;
 
+_TP_AVAILABLE_IN_0_16
 TpAccount *tp_connection_get_account (TpConnection *self);
 
 TpConnectionStatus tp_connection_get_status (TpConnection *self,
     TpConnectionStatusReason *reason);
 
+#ifndef TP_DISABLE_DEPRECATED
+_TP_DEPRECATED_IN_0_20_FOR (tp_connection_get_cm_name)
 const gchar *tp_connection_get_connection_manager_name (TpConnection *self);
+#endif
+
+_TP_AVAILABLE_IN_0_20
+const gchar *tp_connection_get_cm_name (TpConnection *self);
 
 const gchar *tp_connection_get_protocol_name (TpConnection *self);
 
+#ifndef TP_DISABLE_DEPRECATED
+_TP_DEPRECATED_IN_0_20_FOR (tp_connection_get_self_contact)
 TpHandle tp_connection_get_self_handle (TpConnection *self);
+#endif
+
 TpContact *tp_connection_get_self_contact (TpConnection *self);
 
 TpCapabilities * tp_connection_get_capabilities (TpConnection *self);
 
 TpContactInfoFlags tp_connection_get_contact_info_flags (TpConnection *self);
 
+#ifndef TP_DISABLE_DEPRECATED
+_TP_DEPRECATED_IN_0_20_FOR (tp_connection_dup_contact_info_supported_fields)
 GList *tp_connection_get_contact_info_supported_fields (TpConnection *self);
+#endif
+
+_TP_AVAILABLE_IN_0_20
+GList *tp_connection_dup_contact_info_supported_fields (TpConnection *self);
 
 void tp_connection_set_contact_info_async (TpConnection *self,
     GList *info, GAsyncReadyCallback callback,
@@ -153,19 +187,21 @@ gboolean tp_connection_set_contact_info_finish (TpConnection *self,
     GAsyncResult *result, GError **error);
 
 #ifndef TP_DISABLE_DEPRECATED
-gboolean tp_connection_is_ready (TpConnection *self)
-  _TP_GNUC_DEPRECATED_FOR (tp_proxy_is_prepared);
+_TP_DEPRECATED_IN_0_18_FOR (tp_proxy_is_prepared)
+gboolean tp_connection_is_ready (TpConnection *self);
 
+_TP_DEPRECATED_IN_0_18
 gboolean tp_connection_run_until_ready (TpConnection *self,
     gboolean connect, GError **error,
-    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+    GMainLoop **loop);
 
 typedef void (*TpConnectionWhenReadyCb) (TpConnection *connection,
     const GError *error, gpointer user_data);
 
+_TP_DEPRECATED_IN_0_18_FOR (tp_proxy_prepare_async)
 void tp_connection_call_when_ready (TpConnection *self,
     TpConnectionWhenReadyCb callback,
-    gpointer user_data) _TP_GNUC_DEPRECATED_FOR (tp_proxy_prepare_async);
+    gpointer user_data);
 #endif
 
 typedef void (*TpConnectionNameListCb) (const gchar * const *names,
@@ -183,11 +219,19 @@ void tp_connection_init_known_interfaces (void);
 gint tp_connection_presence_type_cmp_availability (TpConnectionPresenceType p1,
   TpConnectionPresenceType p2);
 
+#ifndef TP_DISABLE_DEPRECATED
+_TP_DEPRECATED_IN_0_20_FOR(tp_connection_get_protocol_name)
 gboolean tp_connection_parse_object_path (TpConnection *self, gchar **protocol,
     gchar **cm_name);
+#endif
 
+_TP_AVAILABLE_IN_0_20
 const gchar *tp_connection_get_detailed_error (TpConnection *self,
     const GHashTable **details);
+_TP_AVAILABLE_IN_0_20
+gchar *tp_connection_dup_detailed_error_vardict (TpConnection *self,
+    GVariant **details) G_GNUC_WARN_UNUSED_RESULT;
+
 
 void tp_connection_add_client_interest (TpConnection *self,
     const gchar *interested_in);
@@ -215,10 +259,12 @@ GQuark tp_connection_get_feature_quark_contact_info (void) G_GNUC_CONST;
 
 /* connection-handles.c */
 
+#ifndef TP_DISABLE_DEPRECATED
 typedef void (*TpConnectionHoldHandlesCb) (TpConnection *connection,
     TpHandleType handle_type, guint n_handles, const TpHandle *handles,
     const GError *error, gpointer user_data, GObject *weak_object);
 
+_TP_DEPRECATED_IN_0_20
 void tp_connection_hold_handles (TpConnection *self, gint timeout_ms,
     TpHandleType handle_type, guint n_handles, const TpHandle *handles,
     TpConnectionHoldHandlesCb callback,
@@ -229,13 +275,16 @@ typedef void (*TpConnectionRequestHandlesCb) (TpConnection *connection,
     guint n_handles, const TpHandle *handles, const gchar * const *ids,
     const GError *error, gpointer user_data, GObject *weak_object);
 
+_TP_DEPRECATED_IN_0_20
 void tp_connection_request_handles (TpConnection *self, gint timeout_ms,
     TpHandleType handle_type, const gchar * const *ids,
     TpConnectionRequestHandlesCb callback,
     gpointer user_data, GDestroyNotify destroy, GObject *weak_object);
 
+_TP_DEPRECATED_IN_0_20
 void tp_connection_unref_handles (TpConnection *self,
     TpHandleType handle_type, guint n_handles, const TpHandle *handles);
+#endif
 
 /* connection-avatars.c */
 
@@ -282,21 +331,28 @@ TpAvatarRequirements * tp_connection_get_avatar_requirements (
 
 #define TP_CONNECTION_FEATURE_ALIASING \
   (tp_connection_get_feature_quark_aliasing ())
+_TP_AVAILABLE_IN_0_18
 GQuark tp_connection_get_feature_quark_aliasing (void) G_GNUC_CONST;
 
+_TP_AVAILABLE_IN_0_18
 gboolean tp_connection_can_set_contact_alias (TpConnection *self);
 
 #define TP_CONNECTION_FEATURE_BALANCE \
   (tp_connection_get_feature_quark_balance ())
+_TP_AVAILABLE_IN_0_16
 GQuark tp_connection_get_feature_quark_balance (void) G_GNUC_CONST;
 
+_TP_AVAILABLE_IN_0_16
 gboolean tp_connection_get_balance (TpConnection *self,
     gint *balance, guint *scale, const gchar **currency);
+_TP_AVAILABLE_IN_0_16
 const gchar * tp_connection_get_balance_uri (TpConnection *self);
 
+_TP_AVAILABLE_IN_0_18
 void tp_connection_disconnect_async (TpConnection *self,
     GAsyncReadyCallback callback,
     gpointer user_data);
+_TP_AVAILABLE_IN_0_18
 gboolean tp_connection_disconnect_finish (TpConnection *self,
     GAsyncResult *result,
     GError **error);
@@ -310,16 +366,21 @@ G_BEGIN_DECLS
 /* connection-handles.c again - this has to come after the auto-generated
  * stuff because it uses an auto-generated typedef */
 
+#ifndef TP_DISABLE_DEPRECATED
+_TP_DEPRECATED_IN_0_20_FOR(tp_simple_client_factory_ensure_contact)
 void tp_connection_get_contact_attributes (TpConnection *self,
     gint timeout_ms, guint n_handles, const TpHandle *handles,
     const gchar * const *interfaces, gboolean hold,
     tp_cli_connection_interface_contacts_callback_for_get_contact_attributes callback,
     gpointer user_data, GDestroyNotify destroy, GObject *weak_object);
 
+_TP_DEPRECATED_IN_0_20_FOR(tp_connection_dup_contact_list)
 void tp_connection_get_contact_list_attributes (TpConnection *self,
     gint timeout_ms, const gchar * const *interfaces, gboolean hold,
     tp_cli_connection_interface_contacts_callback_for_get_contact_attributes callback,
     gpointer user_data, GDestroyNotify destroy, GObject *weak_object);
+#endif
+
 GBinding *tp_connection_bind_connection_status_to_property (TpConnection *self,
     gpointer target, const char *target_property, gboolean invert);
 
