@@ -29,6 +29,7 @@
 
 #define DEBUG_FLAG TP_DEBUG_CHANNEL
 #include "telepathy-glib/debug-internal.h"
+#include "telepathy-glib/util-internal.h"
 
 #include "_gen/telepathy-interfaces.h"
 
@@ -136,8 +137,7 @@ tp_contact_search_result_dispose (GObject *object)
 
   tp_clear_pointer (&self->priv->identifier, g_free);
 
-  g_list_foreach (self->priv->fields, (GFunc) tp_contact_info_field_free, NULL);
-  tp_clear_pointer (&self->priv->fields, g_list_free);
+  tp_clear_pointer (&self->priv->fields, tp_contact_info_list_free);
 
   G_OBJECT_CLASS (tp_contact_search_result_parent_class)->dispose (object);
 }
@@ -251,6 +251,8 @@ tp_contact_search_result_get_field (TpContactSearchResult *self,
  * Returns: (transfer container) (element-type TelepathyGLib.ContactInfoField):
  *  a #GList of #TpContactInfoField for the specified contact. You should free
  *  it when you're done with g_list_free().
+ * Deprecated: Since 0.19.9. New code should use
+ *  tp_contact_search_result_dup_fields() instead.
  */
 GList *
 tp_contact_search_result_get_fields (TpContactSearchResult *self)
@@ -259,3 +261,23 @@ tp_contact_search_result_get_fields (TpContactSearchResult *self)
 
   return g_list_copy (self->priv->fields);
 }
+
+/**
+ * tp_contact_search_result_dup_fields:
+ * @self: a search result
+ *
+ * <!-- -->
+ *
+ * Returns: (transfer full) (element-type TelepathyGLib.ContactInfoField):
+ *  a #GList of #TpContactInfoField for the specified contact. You should free
+ *  it when you're done with tp_contact_info_list_free().
+ * Since: 0.19.9
+ */
+GList *
+tp_contact_search_result_dup_fields (TpContactSearchResult *self)
+{
+  g_return_val_if_fail (TP_IS_CONTACT_SEARCH_RESULT (self), NULL);
+
+  return _tp_g_list_copy_deep (self->priv->fields,
+      (GCopyFunc) tp_contact_info_field_copy, NULL);
+}
