@@ -1,3 +1,4 @@
+/*<private_header>*/
 /* Deprecated functions still used internally
  *
  * Copyright (C) 2011 Collabora Ltd. <http://www.collabora.co.uk/>
@@ -24,6 +25,7 @@
 #include <telepathy-glib/base-client.h>
 #include <telepathy-glib/channel-request.h>
 #include <telepathy-glib/client-channel-factory.h>
+#include <telepathy-glib/defs.h>
 
 G_BEGIN_DECLS
 
