@@ -17,11 +17,14 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
+#include "config.h"
+
 #include "telepathy-glib/proxy-subclass.h"
 #include "telepathy-glib/proxy-internal.h"
 
 #define DEBUG_FLAG TP_DEBUG_PROXY
 #include "telepathy-glib/debug-internal.h"
+#include <telepathy-glib/util.h>
 
 #if 0
 #define MORE_DEBUG DEBUG
@@ -312,7 +315,7 @@ tp_proxy_pending_call_cancel (TpProxyPendingCall *pc)
 
       if (pc->args != NULL)
         {
-          g_value_array_free (pc->args);
+          tp_value_array_free (pc->args);
           pc->args = NULL;
         }
     }
@@ -361,7 +364,7 @@ tp_proxy_pending_call_free (TpProxyPendingCall *pc)
   pc->error = NULL;
 
   if (pc->args != NULL)
-    g_value_array_free (pc->args);
+    tp_value_array_free (pc->args);
 
   pc->args = NULL;
 
