@@ -134,7 +134,6 @@ static void
 setup (Test *test,
     gconstpointer data)
 {
-  g_type_init ();
   tp_debug_set_flags ("all");
 
   test->mainloop = g_main_loop_new (NULL, FALSE);
@@ -276,7 +275,7 @@ finish_prepare_action (GObject *source_object,
 
   g_assert (test->am == am);
   test->prepared = tp_account_manager_prepare_finish (am, res, &test->error);
-  is_prepared_reply = tp_account_manager_is_prepared (test->am,
+  is_prepared_reply = tp_proxy_is_prepared (test->am,
       TP_ACCOUNT_MANAGER_FEATURE_CORE);
   g_assert_cmpint (is_prepared_reply, ==, test->prepared);
   script_continue (test);
@@ -338,7 +337,7 @@ assert_core_not_ready_action (gpointer script_data,
 {
   Test *test = (Test *) script_data;
 
-  g_assert (!tp_account_manager_is_prepared (test->am,
+  g_assert (!tp_proxy_is_prepared (test->am,
       TP_ACCOUNT_MANAGER_FEATURE_CORE));
 
   script_continue (script_data);
@@ -350,7 +349,7 @@ assert_feature_not_ready_action (gpointer script_data,
 {
   Test *test = (Test *) script_data;
 
-  g_assert (!tp_account_manager_is_prepared (test->am,
+  g_assert (!tp_proxy_is_prepared (test->am,
       g_quark_from_string ((gchar *) user_data)));
 
   g_free (user_data);
@@ -410,7 +409,7 @@ ensure_action (gpointer script_data,
   Test *test = (Test *) script_data;
   g_assert (test != NULL);
   g_assert (test->am != NULL);
-  g_assert (tp_account_manager_is_prepared (test->am, TP_ACCOUNT_MANAGER_FEATURE_CORE));
+  g_assert (tp_proxy_is_prepared (test->am, TP_ACCOUNT_MANAGER_FEATURE_CORE));
   test->account = tp_account_manager_ensure_account (test->am,
       path);
 
@@ -437,7 +436,7 @@ finish_account_prepare_action (GObject *source_object,
 
   g_assert (test->account == account);
   test->prepared = tp_account_prepare_finish (account, res, &test->error);
-  g_assert (test->prepared == tp_account_is_prepared (account, TP_ACCOUNT_FEATURE_CORE));
+  g_assert (test->prepared == tp_proxy_is_prepared (account, TP_ACCOUNT_FEATURE_CORE));
 
   script_continue (test);
 }
@@ -813,5 +812,5 @@ main (int argc,
               test_most_available_one_unset, teardown_service);
   g_test_add ("/am/most-available/two-unset", Test, NULL, setup_service,
               test_most_available_two_unset, teardown_service);
-  return g_test_run ();
+  return tp_tests_run_with_bus ();
 }
