@@ -22,7 +22,6 @@ static void
 setup (Test *test,
     gconstpointer data)
 {
-  g_type_init ();
   tp_debug_set_flags ("all");
 
   tp_tests_create_and_connect_conn (TP_TESTS_TYPE_SIMPLE_CONNECTION,
@@ -50,9 +49,11 @@ test_new_from_parts (Test *test,
   TpHandle sender;
   TpMessage *msg;
   const GHashTable *part;
+  GVariant *part_vardict;
   gboolean valid;
+  const gchar *s;
 
-  parts = _tp_g_ptr_array_new_full (2, (GDestroyNotify) g_hash_table_unref);
+  parts = g_ptr_array_new_full (2, (GDestroyNotify) g_hash_table_unref);
 
   sender = tp_handle_ensure (test->contact_repo, "bob", NULL, &test->error);
   g_assert_no_error (test->error);
@@ -93,6 +94,16 @@ test_new_from_parts (Test *test,
   g_assert_cmpstr (tp_asv_get_string (part, "content"), ==,
       "Badger");
 
+  part_vardict = tp_message_dup_part (msg, 1);
+  g_assert_cmpstr (g_variant_get_type_string (part_vardict), ==, "a{sv}");
+  valid = g_variant_lookup (part_vardict, "content-type", "&s", &s);
+  g_assert (valid);
+  g_assert_cmpstr (s, ==, "text/plain");
+  valid = g_variant_lookup (part_vardict, "content", "&s", &s);
+  g_assert (valid);
+  g_assert_cmpstr (s, ==, "Badger");
+  g_variant_unref (part_vardict);
+
   g_assert_cmpuint (tp_message_get_message_type (msg), ==,
       TP_CHANNEL_TEXT_MESSAGE_TYPE_NOTICE);
   g_assert_cmpuint (tp_cm_message_get_sender (msg), ==, sender);
@@ -283,8 +294,8 @@ test_take_message (Test *test,
 
   tp_message_set_uint32 (msg, 0, "message-type",
       TP_CHANNEL_TEXT_MESSAGE_TYPE_DELIVERY_REPORT);
-  tp_message_set_uint32 (msg, 0, "delivery-status",
-      TP_DELIVERY_STATUS_DELIVERED);
+  tp_message_set_variant (msg, 0, "delivery-status",
+      g_variant_new_uint32 (TP_DELIVERY_STATUS_DELIVERED));
   tp_cm_message_take_message (msg, 0, "delivery-echo", echo);
 
   /* ensure the message was destroyed */
@@ -329,5 +340,5 @@ main (int argc,
   g_test_add (TEST_PREFIX "take_message", Test, NULL, setup,
       test_take_message, teardown);
 
-  return g_test_run ();
+  return tp_tests_run_with_bus ();
 }
