@@ -48,7 +48,6 @@ setup (Test *test,
   GError *error = NULL;
   GQuark features[] = { TP_CONNECTION_FEATURE_CONNECTED, 0 };
 
-  g_type_init ();
   tp_debug_set_flags ("all");
   test->dbus = tp_tests_dbus_daemon_dup_or_die ();
 
@@ -116,7 +115,7 @@ teardown (Test *test,
   tp_tests_connection_assert_disconnect_succeeds (conn);
 
   g_assert (!tp_connection_run_until_ready (conn, FALSE, &error, NULL));
-  g_assert_error (error, TP_ERRORS, TP_ERROR_CANCELLED);
+  g_assert_error (error, TP_ERROR, TP_ERROR_CANCELLED);
   g_clear_error (&error);
 
   test->service_conn_as_base = NULL;
@@ -153,13 +152,11 @@ int
 main (int argc,
       char **argv)
 {
-  g_type_init ();
-
   tp_tests_abort_after (5);
   g_test_init (&argc, &argv, NULL);
 
   g_test_add ("/conn/aliasing/user-set", Test, NULL,
       setup, test_user_set, teardown);
 
-  return g_test_run ();
+  return tp_tests_run_with_bus ();
 }
