@@ -14,6 +14,8 @@
  * notice and this notice are preserved.
  */
 
+#include "config.h"
+
 #include <telepathy-glib/connection.h>
 #include <telepathy-glib/dbus.h>
 #include <telepathy-glib/debug.h>
@@ -292,7 +294,6 @@ main (int argc,
   /* Setup */
 
   tp_tests_abort_after (10);
-  g_type_init ();
   tp_debug_set_flags ("all");
   dbus = tp_tests_dbus_daemon_dup_or_die ();
 
@@ -328,9 +329,7 @@ main (int argc,
 
   /* Teardown */
 
-  MYASSERT (tp_cli_connection_run_disconnect (client_conn, -1, &error, NULL),
-      "");
-  g_assert_no_error (error);
+  tp_tests_connection_assert_disconnect_succeeds (client_conn);
 
   service_conn_as_base = NULL;
   g_object_unref (service_conn);
