@@ -158,13 +158,12 @@ main (int argc,
 {
   GObject *stub;
   GError *error_out = NULL;
-  GError err = { TP_ERRORS, TP_ERROR_INVALID_ARGUMENT, "Because I said so" };
+  GError err = { TP_ERROR, TP_ERROR_INVALID_ARGUMENT, "Because I said so" };
   TpProxySignalConnection *sc;
   gpointer tmp_obj;
   gboolean freed = FALSE;
 
   tp_tests_abort_after (10);
-  g_type_init ();
   tp_debug_set_flags ("all");
 
   freed_user_data = tp_intset_sized_new (N_DAEMONS);
