@@ -219,7 +219,6 @@ main (int argc,
   GHashTable *parameters;
 
   tp_tests_abort_after (10);
-  g_type_init ();
   tp_debug_set_flags ("all");
   dbus = tp_tests_dbus_daemon_dup_or_die ();
 
@@ -272,32 +271,31 @@ main (int argc,
       g_hash_table_unref (properties);
     }
 
-  handle = tp_tests_connection_run_request_contact_handle (conn,
-      "them@example.com");
-
     {
       GHashTable *request = tp_asv_new (
           TP_PROP_CHANNEL_CHANNEL_TYPE,
               G_TYPE_STRING, TP_IFACE_CHANNEL_TYPE_TEXT,
           TP_PROP_CHANNEL_TARGET_HANDLE_TYPE,
               G_TYPE_UINT, TP_HANDLE_TYPE_CONTACT,
-          TP_PROP_CHANNEL_TARGET_HANDLE, G_TYPE_UINT, handle,
+          TP_PROP_CHANNEL_TARGET_ID, G_TYPE_STRING, "them@example.com",
           NULL);
 
       tp_cli_connection_interface_requests_run_create_channel (conn, -1,
-          request, &chan_path, NULL, &error, NULL);
+          request, &chan_path, &parameters, &error, NULL);
       g_assert_no_error (error);
 
       g_hash_table_unref (request);
     }
 
-  chan = tp_channel_new (conn, chan_path, TP_IFACE_CHANNEL_TYPE_TEXT,
-      TP_HANDLE_TYPE_CONTACT, handle, &error);
+  chan = tp_channel_new_from_properties (conn, chan_path, parameters, &error);
   g_assert_no_error (error);
+  g_hash_table_unref (parameters);
 
   tp_channel_run_until_ready (chan, &error, NULL);
   g_assert_no_error (error);
 
+  handle = tp_channel_get_handle (chan, NULL);
+
   MYASSERT (tp_cli_channel_type_text_connect_to_received (chan, on_received,
       NULL, NULL, NULL, NULL) != NULL, "");
   MYASSERT (tp_cli_channel_type_text_connect_to_sent (chan, on_sent,
@@ -973,7 +971,7 @@ main (int argc,
           ids, &error, NULL),
           "");
       MYASSERT (error != NULL, "");
-      MYASSERT (error->domain == TP_ERRORS, "%s",
+      MYASSERT (error->domain == TP_ERROR, "%s",
           g_quark_to_string (error->domain));
       MYASSERT (error->code == TP_ERROR_INVALID_ARGUMENT, "%u", error->code);
       g_error_free (error);
