@@ -59,7 +59,6 @@ setup (Test *test,
   TpBaseConnectionManager *service_cm_as_base;
   gboolean ok;
 
-  g_type_init ();
   tp_debug_set_flags ("all");
 
   test->mainloop = g_main_loop_new (NULL, FALSE);
@@ -362,5 +361,5 @@ main (int argc,
   g_test_add ("/params-cm/get-parameters-bad-proto", Test, NULL, setup,
       test_get_parameters_bad_proto, teardown);
 
-  return g_test_run ();
+  return tp_tests_run_with_bus ();
 }
