@@ -10,7 +10,7 @@
 
 #include "config.h"
 
-#include <telepathy-glib/channel-manager.h>
+#include <telepathy-glib/telepathy-glib.h>
 
 #include "simple-channel-manager.h"
 #include "util.h"
@@ -63,7 +63,8 @@ tp_tests_simple_channel_manager_request (TpChannelManager *manager,
 
   tokens = g_slist_append (NULL, request_token);
 
-  path = g_strdup_printf ("%s/Channel", self->conn->object_path);
+  path = g_strdup_printf ("%s/Channel",
+      tp_base_connection_get_object_path (self->conn));
 
   channel = tp_tests_object_new_static_class (
       TP_TESTS_TYPE_ECHO_CHANNEL,
