@@ -13,7 +13,7 @@
 #define __TP_TESTS_SIMPLE_CONN_H__
 
 #include <glib-object.h>
-#include <telepathy-glib/base-connection.h>
+#include <telepathy-glib/telepathy-glib.h>
 
 G_BEGIN_DECLS
 
@@ -61,6 +61,22 @@ void tp_tests_simple_connection_inject_disconnect (
 void tp_tests_simple_connection_set_identifier (TpTestsSimpleConnection *self,
     const gchar *identifier);
 
+gchar * tp_tests_simple_connection_ensure_text_chan (
+    TpTestsSimpleConnection *self,
+    const gchar *target_id,
+    GHashTable **props);
+
+void tp_tests_simple_connection_set_get_self_handle_error (
+    TpTestsSimpleConnection *self,
+    GQuark domain,
+    gint code,
+    const gchar *message);
+
+gchar * tp_tests_simple_connection_ensure_room_list_chan (
+    TpTestsSimpleConnection *self,
+    const gchar *server,
+    GHashTable **props);
+
 G_END_DECLS
 
 #endif /* #ifndef __TP_TESTS_SIMPLE_CONN_H__ */
