@@ -13,10 +13,7 @@
 #define __TEST_TEXT_CHANNEL_GROUP_H__
 
 #include <glib-object.h>
-#include <telepathy-glib/base-connection.h>
-#include <telepathy-glib/base-channel.h>
-#include <telepathy-glib/group-mixin.h>
-#include <telepathy-glib/text-mixin.h>
+#include <telepathy-glib/telepathy-glib.h>
 
 G_BEGIN_DECLS
 
@@ -68,6 +65,9 @@ struct _TpTestsTextChannelGroup {
 
 void tp_tests_text_channel_group_join (TpTestsTextChannelGroup *self);
 
+void tp_tests_text_channel_set_password (TpTestsTextChannelGroup *self,
+    const gchar *password);
+
 G_END_DECLS
 
 #endif /* #ifndef __TEST_TEXT_CHANNEL_GROUP_H__ */
