@@ -13,9 +13,7 @@
 #define __TP_TESTS_TEXT_CHANNEL_NULL_H__
 
 #include <glib-object.h>
-#include <telepathy-glib/base-connection.h>
-#include <telepathy-glib/text-mixin.h>
-#include <telepathy-glib/group-mixin.h>
+#include <telepathy-glib/telepathy-glib.h>
 
 G_BEGIN_DECLS
 
@@ -130,6 +128,8 @@ GType tp_tests_props_group_text_channel_get_type (void);
 
 void tp_tests_text_channel_null_close (TpTestsTextChannelNull *self);
 
+GHashTable * tp_tests_text_channel_get_props (TpTestsTextChannelNull *self);
+
 G_END_DECLS
 
 #endif /* #ifndef __TP_TESTS_TEXT_CHANNEL_NULL_H__ */
